@@ -32,19 +32,18 @@ public:
     QMap<ElisaUtils::PlayListEntryType, ViewParameters> mChildViews = {
         {ElisaUtils::Album, {{},
                              QUrl{QStringLiteral("image://icon/view-media-track")},
-                             ViewManager::ListView,
+                             ViewManager::TrackView,
                              ViewManager::GenericDataModel,
                              ElisaUtils::FilterById,
                              ElisaUtils::Track,
-                             Qt::DisplayRole,
-                             {Qt::DisplayRole},
-                             {i18nc("@title:inmenu", "Title")},
+                             DataTypes::TrackNumberRole,
+                             {DataTypes::TrackNumberRole, Qt::DisplayRole},
+                             {i18nc("@title:inmenu", "Track Number"), i18nc("@title:inmenu", "Title")},
                              Qt::AscendingOrder,
-                             {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
+                             {i18nc("@item:inmenu", "Ascending"), i18nc("@item:inmenu", "Descending"),
+                              i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
                              ViewManager::SingleAlbum,
-                             ViewManager::DiscHeaders,
-                             ViewManager::IsTrack,
-                             ViewManager::IsFlatModel}},
+                             ViewManager::DiscHeaders}},
         {ElisaUtils::Genre, {{},
                              QUrl{QStringLiteral("image://icon/view-media-artist")},
                              ViewManager::GridView,
@@ -58,8 +57,7 @@ public:
                              {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
                              QUrl{QStringLiteral("image://icon/view-media-artist")},
                              ViewManager::DelegateWithoutSecondaryText,
-                             ViewManager::ViewHideRating,
-                             ViewManager::IsFlatModel}},
+                             ViewManager::ViewHideRating}},
         {ElisaUtils::Artist, {{},
                               QUrl{QStringLiteral("image://icon/view-media-album-cover")},
                               ViewManager::GridView,
@@ -73,8 +71,7 @@ public:
                               {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First")},
                               QUrl{QStringLiteral("image://icon/media-default-album")},
                               ViewManager::DelegateWithSecondaryText,
-                              ViewManager::ViewShowRating,
-                              ViewManager::IsFlatModel}},
+                              ViewManager::ViewShowRating}},
         {ElisaUtils::Container, {{},
                                  QUrl{QStringLiteral("image://icon/folder")},
                                  ViewManager::GridView,
@@ -88,17 +85,16 @@ public:
                                  {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
                                  QUrl{QStringLiteral("image://icon/folder")},
                                  ViewManager::DelegateWithoutSecondaryText,
-                                 ViewManager::ViewHideRating,
-                                 ViewManager::IsFlatModel}},
+                                 ViewManager::ViewHideRating}},
     };
 
     int mViewIndex = -1;
 
     int mInitialIndex = -1;
 
-    QList<ViewParameters> mViewParametersStack = (mViewsListData ? QList<ViewParameters>{mViewsListData->viewParameters(0)} : QList<ViewParameters>{});
+    QString mInitialFilesViewPath = QDir::rootPath();
 
-    ViewParameters mNextViewParameters;
+    QList<ViewParameters> mViewParametersStack = (mViewsListData ? QList<ViewParameters>{mViewsListData->viewParameters(0)} : QList<ViewParameters>{});
 };
 
 ViewManager::ViewManager(QObject *parent)
@@ -122,33 +118,39 @@ ViewsListData *ViewManager::viewsData() const
     return d->mViewsListData;
 }
 
+QString ViewManager::initialFilesViewPath() const
+{
+    return d->mInitialFilesViewPath;
+}
+
 ViewManager::~ViewManager() = default;
 
 void ViewManager::openView(int viewIndex)
 {
     qCDebug(orgKdeElisaViews()) << "ViewManager::openView" << viewIndex << d->mViewParametersStack.size() << d->mViewsListData;
 
-    if (!d->mViewsListData || d->mViewsListData->isEmpty() || !d->mViewsListData->isFullyInitialized()) {
+    if (!d->mViewsListData || d->mViewsListData->isEmpty()) {
         return;
     }
 
+    d->mViewParametersStack.clear();
+
     if (viewIndex < 0 || viewIndex >= d->mViewsListData->count()) {
         viewIndex = 0;
     }
 
-    const auto &viewParameters = d->mViewsListData->viewParameters(viewIndex);
+    auto viewParameters = d->mViewsListData->viewParameters(viewIndex);
 
-    qCDebug(orgKdeElisaViews()) << "ViewManager::openView" << "selected view" << viewIndex;
+    qCDebug(orgKdeElisaViews()) << "ViewManager::openView" << "changing view" << viewIndex;
 
-    if (d->mViewParametersStack.isEmpty() || viewParameters != d->mViewParametersStack.back()) {
-        qCDebug(orgKdeElisaViews()) << "ViewManager::openView" << "changing view";
-        d->mViewIndex = viewIndex;
-        Q_EMIT viewIndexChanged();
+    d->mViewIndex = viewIndex;
+    Q_EMIT viewIndexChanged();
 
-        d->mNextViewParameters = viewParameters;
-        applyFilter(d->mNextViewParameters, viewParameters.mMainTitle, d->mNextViewParameters);
-        openViewFromData(d->mNextViewParameters);
+    applyFilter(viewParameters, viewParameters.mMainTitle, viewParameters);
+    if (viewParameters.mDataType == ElisaUtils::FileName) { // Folder view
+        viewParameters.mDataFilter[DataTypes::FilePathRole] = QUrl::fromLocalFile(d->mInitialFilesViewPath);
     }
+    openViewFromData(viewParameters);
 }
 
 void ViewManager::openChildView(const DataTypes::MusicDataType &fullData)
@@ -167,7 +169,7 @@ void ViewManager::openChildView(const DataTypes::MusicDataType &fullData)
         return;
     }
 
-    if (!d->mViewsListData || d->mViewsListData->isEmpty() || !d->mViewsListData->isFullyInitialized()) {
+    if (!d->mViewsListData || d->mViewsListData->isEmpty()) {
         return;
     }
 
@@ -191,61 +193,32 @@ void ViewManager::openChildView(const DataTypes::MusicDataType &fullData)
 
     applyFilter(nextViewParameters, title, lastView);
 
+    // Prevent the user from clicking the same view other and over again
+    if (this->isSameView(nextViewParameters, lastView)) {
+        return;
+    }
+
     if (dataType == ElisaUtils::Album && nextViewParameters.mDataFilter[DataTypes::IsSingleDiscAlbumRole].toBool())
     {
         nextViewParameters.mAlbumViewStyle = NoDiscHeaders;
     }
 
-    d->mNextViewParameters = nextViewParameters;
-
-    if (lastView.mDataType != dataType) {
-        for(int i = 0; i < d->mViewsListData->count(); ++i) {
-            if (d->mViewsListData->viewParameters(i).mDataType == dataType) {
-                d->mViewIndex = i;
-                Q_EMIT viewIndexChanged();
-
-                nextViewParameters = d->mViewsListData->viewParameters(i);
-                break;
-            }
-        }
-    }
-
     openViewFromData(nextViewParameters);
 }
 
 void ViewManager::openAlbumView(const QString &title, const QString &artist, qulonglong databaseId, const QUrl &albumCoverUrl)
 {
-    if (d->mViewsListData->embeddedCategory() == ElisaUtils::Album) {
-        auto index = d->mViewsListData->indexFromEmbeddedDatabaseId(databaseId);
-
-        if (index == -1) {
-            return;
-        }
-
-        openView(index);
-    } else {
-        openChildView({{DataTypes::ElementTypeRole, ElisaUtils::Album},
-                       {DataTypes::DatabaseIdRole, databaseId},
-                       {DataTypes::TitleRole, title},
-                       {DataTypes::ArtistRole, artist},
-                       {DataTypes::ImageUrlRole, albumCoverUrl},});
-    }
+    openChildView({{DataTypes::ElementTypeRole, ElisaUtils::Album},
+                   {DataTypes::DatabaseIdRole, databaseId},
+                   {DataTypes::TitleRole, title},
+                   {DataTypes::ArtistRole, artist},
+                   {DataTypes::ImageUrlRole, albumCoverUrl},});
 }
 
 void ViewManager::openArtistView(const QString &artist)
 {
-    if (d->mViewsListData->embeddedCategory() == ElisaUtils::Artist) {
-        auto index = d->mViewsListData->indexFromEmbeddedName(artist);
-
-        if (index == -1) {
-            return;
-        }
-
-        openView(index);
-    } else {
-        openChildView({{DataTypes::ElementTypeRole, ElisaUtils::Artist},
-                       {DataTypes::TitleRole, artist},});
-    }
+    openChildView({{DataTypes::ElementTypeRole, ElisaUtils::Artist},
+                   {DataTypes::TitleRole, artist},});
 }
 
 void ViewManager::openNowPlaying()
@@ -253,30 +226,10 @@ void ViewManager::openNowPlaying()
     openView(0);
 }
 
-void ViewManager::viewIsLoaded()
-{
-    qCDebug(orgKdeElisaViews()) << "ViewManager::viewIsLoaded" << d->mViewParametersStack.size()
-                                << d->mViewsListData;
-
-    if (!d->mViewParametersStack.size()) {
-        return;
-    }
-
-    if (d->mNextViewParameters.mIsValid && d->mNextViewParameters != d->mViewParametersStack.back()) {
-        openViewFromData(d->mNextViewParameters);
-    }
-}
-
 void ViewManager::openViewFromData(const ViewParameters &viewParamaters)
 {
     qCDebug(orgKdeElisaViews()) << "ViewManager::openViewFromData" << d->mViewParametersStack.size();
 
-    const auto viewsCountToRemove = d->mViewParametersStack.size() + 1 - viewParamaters.mDepth;
-    for (int i = 0; i < viewsCountToRemove; ++i) {
-        qCDebug(orgKdeElisaViews()) << "ViewManager::openViewFromData" << "pop_back";
-        d->mViewParametersStack.pop_back();
-    }
-
     QAbstractItemModel *newModel = nullptr;
     QAbstractProxyModel *proxyModel = nullptr;
 
@@ -317,8 +270,7 @@ void ViewManager::openViewFromData(const ViewParameters &viewParamaters)
                                     << viewParamaters.mMainImage << viewParamaters.mDataType
                                     << viewParamaters.mModelType << viewParamaters.mFallbackItemIcon
                                     << viewParamaters.mDataFilter
-                                    << viewParamaters.mViewCanBeRated << viewParamaters.mShowSecondaryTextOnDelegates
-                                    << viewParamaters.mIsTreeModel;
+                                    << viewParamaters.mViewCanBeRated << viewParamaters.mShowSecondaryTextOnDelegates;
 
         auto configurationData = std::make_unique<ViewConfigurationData>(viewParamaters.mFilterType, viewParamaters.mDepth,
                                                                          viewParamaters.mMainTitle, viewParamaters.mSecondaryTitle,
@@ -330,14 +282,14 @@ void ViewManager::openViewFromData(const ViewParameters &viewParamaters)
                                                                          computePreferredSortOrder(viewParamaters.mSortOrder, viewParamaters.mFilterType),
                                                                          viewParamaters.mSortOrderNames,
                                                                          viewParamaters.mViewCanBeRated, viewParamaters.mShowSecondaryTextOnDelegates,
-                                                                         viewParamaters.mIsTreeModel);
+                                                                         computePreferredViewStyle(GridStyle, viewParamaters.mDataType));
 
         QQmlEngine::setObjectOwnership(configurationData.get(), QQmlEngine::JavaScriptOwnership);
 
         Q_EMIT openGridView(configurationData.release());
         break;
     }
-    case ViewPresentationType::ListView:
+    case ViewPresentationType::TrackView:
     {
         qCDebug(orgKdeElisaViews()) << "ViewManager::openViewFromData" << viewParamaters.mFilterType
                                     << viewParamaters.mDepth << viewParamaters.mMainTitle << viewParamaters.mSecondaryTitle
@@ -345,8 +297,7 @@ void ViewManager::openViewFromData(const ViewParameters &viewParamaters)
                                     << viewParamaters.mModelType << viewParamaters.mDataType
                                     << viewParamaters.mDataFilter << viewParamaters.mSortRole
                                     << viewParamaters.mSortOrder << viewParamaters.mAlbumCardinality
-                                    << viewParamaters.mAlbumViewStyle << viewParamaters.mRadioSpecificStyle
-                                    << viewParamaters.mIsTreeModel;
+                                    << viewParamaters.mAlbumViewStyle;
 
         auto configurationData = std::make_unique<ViewConfigurationData>(viewParamaters.mFilterType, viewParamaters.mDepth,
                                                                          viewParamaters.mMainTitle, viewParamaters.mSecondaryTitle,
@@ -356,12 +307,11 @@ void ViewManager::openViewFromData(const ViewParameters &viewParamaters)
                                                                          viewParamaters.mSortRoles, viewParamaters.mSortRoleNames,
                                                                          computePreferredSortOrder(viewParamaters.mSortOrder, viewParamaters.mFilterType),
                                                                          viewParamaters.mSortOrderNames,
-                                                                         viewParamaters.mAlbumCardinality, viewParamaters.mAlbumViewStyle,
-                                                                         viewParamaters.mRadioSpecificStyle, viewParamaters.mIsTreeModel);
+                                                                         viewParamaters.mAlbumCardinality, viewParamaters.mAlbumViewStyle);
 
         QQmlEngine::setObjectOwnership(configurationData.get(), QQmlEngine::JavaScriptOwnership);
 
-        Q_EMIT openListView(configurationData.release());
+        Q_EMIT openTrackView(configurationData.release());
         break;
     }
     case ContextView:
@@ -404,11 +354,9 @@ void ViewManager::applyFilter(ViewParameters &nextViewParameters,
 QString ViewManager::buildViewId() const
 {
     const auto &entryTypeMetaEnum = QMetaEnum::fromType<ElisaUtils::PlayListEntryType>();
-    QString viewId;
 
-    for (const auto &oneView : std::as_const(d->mViewParametersStack)) {
-        viewId += QString::fromLatin1(entryTypeMetaEnum.valueToKey(oneView.mDataType)) + QStringLiteral("::");
-    }
+    const auto currView = d->mViewParametersStack.back();
+    const auto viewId = QString::fromLatin1(entryTypeMetaEnum.valueToKey(currView.mDataType));
 
     return viewId;
 }
@@ -417,11 +365,7 @@ QStringList::iterator ViewManager::findViewPreference(QStringList &list, const Q
 {
     auto itViewPreference = list.end();
     for(itViewPreference = list.begin(); itViewPreference != list.end(); ++itViewPreference) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        auto parts = itViewPreference->splitRef(QStringLiteral("=="));
-#else
         auto parts = QStringView(*itViewPreference).split(QStringLiteral("=="));
-#endif
         if (parts.size() != 2) {
             continue;
         }
@@ -433,33 +377,20 @@ QStringList::iterator ViewManager::findViewPreference(QStringList &list, const Q
     return itViewPreference;
 }
 
-Qt::SortOrder ViewManager::computePreferredSortOrder(Qt::SortOrder initialValue, ElisaUtils::FilterType filterType) const
+template<typename T>
+T ViewManager::computeViewPreference(const T initialValue, QStringList &preferences) const
 {
-    switch (filterType)
-    {
-    case ElisaUtils::FilterByRecentlyPlayed:
-    case ElisaUtils::FilterByFrequentlyPlayed:
-        return Qt::DescendingOrder;
-    default:
-        break;
-    }
+    const auto viewId = buildViewId();
+    const auto itViewPreference = findViewPreference(preferences, viewId);
 
-    auto currentSortOrderPreferences = Elisa::ElisaConfiguration::sortOrderPreferences();
-    auto viewId = buildViewId();
-    auto itViewPreference = findViewPreference(currentSortOrderPreferences, viewId);
-
-    if (itViewPreference != currentSortOrderPreferences.end()) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        auto result = itViewPreference->splitRef(QStringLiteral("=="));
-#else
-        auto result = QStringView(*itViewPreference).split(QStringLiteral("=="));
-#endif
+    if (itViewPreference != preferences.end()) {
+        const auto result = QStringView(*itViewPreference).split(QStringLiteral("=="));
         if (result.size() == 2) {
-            const auto &sortOrderMetaEnum = QMetaEnum::fromType<Qt::SortOrder>();
+            const auto &sortOrderMetaEnum = QMetaEnum::fromType<T>();
             bool conversionOk;
-            auto newValue = static_cast<Qt::SortOrder>(sortOrderMetaEnum.keyToValue(result[1].toLatin1().data(), &conversionOk));
+            auto newValue = static_cast<T>(sortOrderMetaEnum.keyToValue(result[1].toLatin1().data(), &conversionOk));
             if (conversionOk) {
-                initialValue = newValue;
+                return newValue;
             }
         }
     }
@@ -467,39 +398,78 @@ Qt::SortOrder ViewManager::computePreferredSortOrder(Qt::SortOrder initialValue,
     return initialValue;
 }
 
-int ViewManager::computePreferredSortRole(int initialValue, ElisaUtils::FilterType filterType) const
+template<typename T>
+void ViewManager::updateViewPreference(const T newValue, QStringList &preferences) const
+{
+    const auto viewId = buildViewId();
+    const auto itViewPreference = findViewPreference(preferences, viewId);
+
+    const auto &sortOrderMetaEnum = QMetaEnum::fromType<T>();
+    const auto enumStringValue = sortOrderMetaEnum.valueToKey(newValue);
+    if (!enumStringValue) {
+        return;
+    }
+    const QString newSortOrderPreference = viewId + QStringLiteral("==") + QString::fromLatin1(enumStringValue);
+
+    if (itViewPreference != preferences.end()) {
+        (*itViewPreference) = newSortOrderPreference;
+    } else {
+        preferences.push_back(newSortOrderPreference);
+    }
+}
+
+bool ViewManager::viewHasDefaultSortRole(const ElisaUtils::FilterType filterType) const
 {
     switch (filterType)
     {
     case ElisaUtils::FilterByRecentlyPlayed:
-        return DataTypes::LastPlayDate;
     case ElisaUtils::FilterByFrequentlyPlayed:
-        return DataTypes::PlayCounter;
+    case ElisaUtils::FilterById: // Tracks in album view
+        return true;
     default:
-        break;
+        return false;
+    }
+}
+bool ViewManager::viewHasDefaultViewStyle(const ElisaUtils::PlayListEntryType entryType) const
+{
+    switch (entryType)
+    {
+    case ElisaUtils::Track:
+    case ElisaUtils::Radio:
+        return true;
+    default:
+        return false;
+    }
+}
+
+Qt::SortOrder ViewManager::computePreferredSortOrder(Qt::SortOrder initialValue, ElisaUtils::FilterType filterType) const
+{
+    if (viewHasDefaultSortRole(filterType)) {
+        return initialValue;
+    }
+
+    auto currentSortOrderPreferences = Elisa::ElisaConfiguration::sortOrderPreferences();
+    return computeViewPreference(initialValue, currentSortOrderPreferences);
+}
+
+int ViewManager::computePreferredSortRole(int initialValue, ElisaUtils::FilterType filterType) const
+{
+    if (viewHasDefaultSortRole(filterType)) {
+        return initialValue;
     }
 
     auto currentSortRolePreferences = Elisa::ElisaConfiguration::sortRolePreferences();
-    auto viewId = buildViewId();
-    auto itViewPreference = findViewPreference(currentSortRolePreferences, viewId);
+    return computeViewPreference(static_cast<DataTypes::ColumnsRoles>(initialValue), currentSortRolePreferences);
+}
 
-    if (itViewPreference != currentSortRolePreferences.end()) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        auto result = itViewPreference->splitRef(QStringLiteral("=="));
-#else
-        auto result = QStringView(*itViewPreference).split(QStringLiteral("=="));
-#endif
-        if (result.size() == 2) {
-            const auto &sortRoleMetaEnum = QMetaEnum::fromType<DataTypes::ColumnsRoles>();
-            bool conversionOk;
-            auto newValue = static_cast<DataTypes::ColumnsRoles>(sortRoleMetaEnum.keyToValue(result[1].toLatin1().data(), &conversionOk));
-            if (conversionOk) {
-                initialValue = newValue;
-            }
-        }
+ViewManager::ViewStyle ViewManager::computePreferredViewStyle(ViewStyle initialValue, ElisaUtils::PlayListEntryType dataType) const
+{
+    if (viewHasDefaultViewStyle(dataType)) {
+        return initialValue;
     }
 
-    return initialValue;
+    auto currentViewStylePreferences = Elisa::ElisaConfiguration::viewStylePreferences();
+    return computeViewPreference(initialValue, currentViewStylePreferences);
 }
 
 void ViewManager::goBack()
@@ -515,7 +485,6 @@ void ViewManager::goBack()
 
     if (d->mViewParametersStack.size() > 1) {
         d->mViewParametersStack.pop_back();
-        d->mNextViewParameters = {};
     }
 
     qCDebug(orgKdeElisaViews()) << "ViewManager::goBack" << d->mViewParametersStack.size();
@@ -534,14 +503,9 @@ void ViewManager::setViewsData(ViewsListData *viewsData)
         d->mViewIndex = d->mInitialIndex;
     }
 
-    if (d->mViewsListData && d->mViewIndex >= 0 && d->mViewIndex < d->mViewsListData->count() && d->mViewsListData->isFullyInitialized()) {
+    if (d->mViewsListData && d->mViewIndex >= 0 && d->mViewIndex < d->mViewsListData->count()) {
         openView(d->mViewIndex);
     }
-
-    if (d->mViewsListData) {
-        connect(d->mViewsListData, &ViewsListData::isFullyInitializedChanged,
-                this, &ViewManager::openInitialView);
-    }
 }
 
 void ViewManager::setInitialIndex(int newIndex)
@@ -557,11 +521,21 @@ void ViewManager::setInitialIndex(int newIndex)
         d->mViewIndex = d->mInitialIndex;
     }
 
-    if (d->mViewsListData && d->mViewIndex >= 0 && d->mViewIndex < d->mViewsListData->count() && d->mViewsListData->isFullyInitialized()) {
+    if (d->mViewsListData && d->mViewIndex >= 0 && d->mViewIndex < d->mViewsListData->count()) {
         openView(d->mViewIndex);
     }
 }
 
+void ViewManager::setInitialFilesViewPath(const QString &initialPath)
+{
+    if (d->mInitialFilesViewPath == initialPath) {
+        return;
+    }
+
+    d->mInitialFilesViewPath = initialPath;
+    Q_EMIT initialFilesViewPathChanged();
+}
+
 void ViewManager::openInitialView()
 {
     openView(d->mInitialIndex);
@@ -569,23 +543,12 @@ void ViewManager::openInitialView()
 
 void ViewManager::sortOrderChanged(Qt::SortOrder sortOrder)
 {
-    auto currentSortOrderPreferences = Elisa::ElisaConfiguration::sortOrderPreferences();
-
-    auto viewId = buildViewId();
-    auto itViewPreference = findViewPreference(currentSortOrderPreferences, viewId);
-
-    const auto &sortOrderMetaEnum = QMetaEnum::fromType<Qt::SortOrder>();
-    auto enumStringValue = sortOrderMetaEnum.valueToKey(sortOrder);
-    if (!enumStringValue) {
+    if (viewHasDefaultSortRole(d->mViewParametersStack.back().mFilterType)) {
         return;
     }
-    QString newSortOrderPreference = viewId + QStringLiteral("==") + QString::fromLatin1(enumStringValue);
 
-    if (itViewPreference != currentSortOrderPreferences.end()) {
-        (*itViewPreference) = newSortOrderPreference;
-    } else {
-        currentSortOrderPreferences.push_back(newSortOrderPreference);
-    }
+    auto currentSortOrderPreferences = Elisa::ElisaConfiguration::sortOrderPreferences();
+    updateViewPreference(sortOrder, currentSortOrderPreferences);
 
     Elisa::ElisaConfiguration::setSortOrderPreferences(currentSortOrderPreferences);
     Elisa::ElisaConfiguration::self()->save();
@@ -593,27 +556,49 @@ void ViewManager::sortOrderChanged(Qt::SortOrder sortOrder)
 
 void ViewManager::sortRoleChanged(int sortRole)
 {
-    auto currentSortRolePreferences = Elisa::ElisaConfiguration::sortRolePreferences();
-
-    auto viewId = buildViewId();
-    auto itViewPreference = findViewPreference(currentSortRolePreferences, viewId);
-
-    const auto &sortRoleMetaEnum = QMetaEnum::fromType<DataTypes::ColumnsRoles>();
-    auto enumStringValue = sortRoleMetaEnum.valueToKey(static_cast<DataTypes::ColumnsRoles>(sortRole));
-    if (!enumStringValue) {
+    if (viewHasDefaultSortRole(d->mViewParametersStack.back().mFilterType)) {
         return;
     }
-    QString newSortRolePreference = viewId + QStringLiteral("==") + QString::fromLatin1(enumStringValue);
 
-    if (itViewPreference != currentSortRolePreferences.end()) {
-        (*itViewPreference) = newSortRolePreference;
-    } else {
-        currentSortRolePreferences.push_back(newSortRolePreference);
-    }
+    auto currentSortRolePreferences = Elisa::ElisaConfiguration::sortRolePreferences();
+    updateViewPreference(static_cast<DataTypes::ColumnsRoles>(sortRole), currentSortRolePreferences);
 
     Elisa::ElisaConfiguration::setSortRolePreferences(currentSortRolePreferences);
     Elisa::ElisaConfiguration::self()->save();
 }
 
+void ViewManager::setViewStyle(const ViewStyle viewStyle)
+{
+    if (viewHasDefaultViewStyle(d->mViewParametersStack.back().mDataType)) {
+        return;
+    }
+
+    auto currentViewStylePreferences = Elisa::ElisaConfiguration::viewStylePreferences();
+    updateViewPreference(viewStyle, currentViewStylePreferences);
+
+    Elisa::ElisaConfiguration::setViewStylePreferences(currentViewStylePreferences);
+    Elisa::ElisaConfiguration::self()->save();
+}
+
+bool ViewManager::isSameView(const ViewParameters &currentView, const ViewParameters &otherView) const {
+    if (currentView.mDataType != otherView.mDataType) {
+        return false;
+    }
+
+    // Best case scenario is matching up database ids
+    if (currentView.mDataFilter.hasDatabaseId() && otherView.mDataFilter.hasDatabaseId()) {
+        return currentView.mDataFilter.databaseId() == otherView.mDataFilter.databaseId();
+    }
+
+    // Unfortunately we don't have access to database ids for most of these types, so handle specific types differently.
+    switch (currentView.mDataType) {
+        case ElisaUtils::PlayListEntryType::Album:
+        case ElisaUtils::PlayListEntryType::Artist:
+            return currentView.mMainTitle == otherView.mMainTitle;
+        default:
+            return false;
+    }
+}
+
 
 #include "moc_viewmanager.cpp"
